package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.BusDeviceHistory;
import com.ruoyi.system.domain.dto.SignDto;

/**
 * 透析管理Service接口
 * 
 * @author zsl
 * @date 2022-06-10
 */
public interface IBusDeviceHistoryService 
{
    /**
     * 查询透析管理
     * 
     * @param id 透析管理主键
     * @return 透析管理
     */
    public BusDeviceHistory selectBusDeviceHistoryById(Long id);

    /**
     * 查询透析管理列表
     * 
     * @param busDeviceHistory 透析管理
     * @return 透析管理集合
     */
    public List<BusDeviceHistory> selectBusDeviceHistoryList(BusDeviceHistory busDeviceHistory);

    /**
     * 新增透析管理
     * 
     * @param busDeviceHistory 透析管理
     * @return 结果
     */
    public int insertBusDeviceHistory(BusDeviceHistory busDeviceHistory);

    /**
     * 修改透析管理
     * 
     * @param busDeviceHistory 透析管理
     * @return 结果
     */
    public int updateBusDeviceHistory(BusDeviceHistory busDeviceHistory);

    /**
     * 批量删除透析管理
     * 
     * @param ids 需要删除的透析管理主键集合
     * @return 结果
     */
    public int deleteBusDeviceHistoryByIds(Long[] ids);

    /**
     * 删除透析管理信息
     * 
     * @param id 透析管理主键
     * @return 结果
     */
    public int deleteBusDeviceHistoryById(Long id);

    /**
     * 签到管理
     *
     * @param sign 患者ID
     * @return 结果
     */
    public int sign( SignDto sign);

    /**
     * 治疗中
     *
     * @param ids 患者ID
     * @return 结果
     */
    public  int cure(Long[] ids , Long[] pids);
}
